@@ -1,7 +1,7 @@
 /*
  * Automated Testing Framework (atf)
  *
- * Copyright (c) 2008, 2009, 2010, 2011 The NetBSD Foundation, Inc.
+ * Copyright (c) 2008 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,8 +28,8 @@
  */
 
 #include <sys/types.h>
-#include <sys/resource.h>
 #include <sys/time.h>
+#include <sys/resource.h>
 #include <sys/wait.h>
 
 #include <errno.h>
@@ -135,13 +135,12 @@ capture_stream_process(void *v, atf_process_child_t *c)
 {
     struct capture_stream *s = v;
 
-    bool eof;
     switch (s->m_base.m_type) {
     case stdout_type:
-        eof = read_line(atf_process_child_stdout(c), &s->m_msg);
+        (void)read_line(atf_process_child_stdout(c), &s->m_msg);
         break;
     case stderr_type:
-        eof = read_line(atf_process_child_stderr(c), &s->m_msg);
+        (void)read_line(atf_process_child_stderr(c), &s->m_msg);
         break;
     default:
         UNREACHABLE;
@@ -690,7 +689,7 @@ static void child_report_pid(void *) ATF_DEFS_ATTRIBUTE_NORETURN;
 
 static
 void
-child_report_pid(void *v)
+child_report_pid(void *v ATF_DEFS_ATTRIBUTE_UNUSED)
 {
     const pid_t pid = getpid();
     if (write(STDOUT_FILENO, &pid, sizeof(pid)) != sizeof(pid))
@@ -731,7 +730,7 @@ ATF_TC_BODY(child_pid, tc)
 
 static
 void
-child_loop(void *v)
+child_loop(void *v ATF_DEFS_ATTRIBUTE_UNUSED)
 {
     for (;;)
         sleep(1);
@@ -739,13 +738,13 @@ child_loop(void *v)
 
 static
 void
-nop_signal(int sig)
+nop_signal(int sig ATF_DEFS_ATTRIBUTE_UNUSED)
 {
 }
 
 static
 void
-child_spawn_loop_and_wait_eintr(void *v)
+child_spawn_loop_and_wait_eintr(void *v ATF_DEFS_ATTRIBUTE_UNUSED)
 {
     atf_process_child_t child;
     atf_process_status_t status;
