@@ -1,7 +1,7 @@
 /*
  * Automated Testing Framework (atf)
  *
- * Copyright (c) 2007, 2008, 2009, 2010 The NetBSD Foundation, Inc.
+ * Copyright (c) 2007 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -85,11 +85,7 @@ ATF_TC_BODY(cleanup_pass, tc)
 }
 ATF_TC_CLEANUP(cleanup_pass, tc)
 {
-    bool cleanup;
-
-    RE(atf_text_to_bool(atf_tc_get_config_var(tc, "cleanup"), &cleanup));
-
-    if (cleanup)
+    if (atf_tc_get_config_var_as_bool(tc, "cleanup"))
         safe_remove(atf_tc_get_config_var(tc, "tmpfile"));
 }
 
@@ -106,11 +102,7 @@ ATF_TC_BODY(cleanup_fail, tc)
 }
 ATF_TC_CLEANUP(cleanup_fail, tc)
 {
-    bool cleanup;
-
-    RE(atf_text_to_bool(atf_tc_get_config_var(tc, "cleanup"), &cleanup));
-
-    if (cleanup)
+    if (atf_tc_get_config_var_as_bool(tc, "cleanup"))
         safe_remove(atf_tc_get_config_var(tc, "tmpfile"));
 }
 
@@ -127,11 +119,7 @@ ATF_TC_BODY(cleanup_skip, tc)
 }
 ATF_TC_CLEANUP(cleanup_skip, tc)
 {
-    bool cleanup;
-
-    RE(atf_text_to_bool(atf_tc_get_config_var(tc, "cleanup"), &cleanup));
-
-    if (cleanup)
+    if (atf_tc_get_config_var_as_bool(tc, "cleanup"))
         safe_remove(atf_tc_get_config_var(tc, "tmpfile"));
 }
 
@@ -432,10 +420,7 @@ ATF_TC_BODY(fork_stop, tc)
  * Helper tests for "t_meta_data".
  * --------------------------------------------------------------------- */
 
-ATF_TC(metadata_no_descr);
-ATF_TC_HEAD(metadata_no_descr, tc)
-{
-}
+ATF_TC_WITHOUT_HEAD(metadata_no_descr);
 ATF_TC_BODY(metadata_no_descr, tc)
 {
 }
@@ -472,23 +457,20 @@ ATF_TC_BODY(srcdir_exists, tc)
  * Helper tests for "t_result".
  * --------------------------------------------------------------------- */
 
-ATF_TC(result_pass);
-ATF_TC_HEAD(result_pass, tc) { }
+ATF_TC_WITHOUT_HEAD(result_pass);
 ATF_TC_BODY(result_pass, tc)
 {
     printf("msg\n");
 }
 
-ATF_TC(result_fail);
-ATF_TC_HEAD(result_fail, tc) { }
+ATF_TC_WITHOUT_HEAD(result_fail);
 ATF_TC_BODY(result_fail, tc)
 {
     printf("msg\n");
     atf_tc_fail("Failure reason");
 }
 
-ATF_TC(result_skip);
-ATF_TC_HEAD(result_skip, tc) { }
+ATF_TC_WITHOUT_HEAD(result_skip);
 ATF_TC_BODY(result_skip, tc)
 {
     printf("msg\n");
